@@ -50,9 +50,11 @@ class ActivityDirector(threading.local):
         return self.activity_manager.create(actor, verb, obj, target=target,
                 related_nodes=related_nodes)
 
-    def create_timeline(self, node):
-        return self.aggregator.create_timeline(node)
+    def create_timeline(self, node_id):
+        return self.aggregator.create_timeline(node_id)
 
+    def get_timeline(self, *args, **kw):
+        return self.aggregator.get_timeline(*args, **kw)
 
 def configure(**conf):
     global _director
